@@ -6,6 +6,7 @@ import numpy as np
 import bisect
 from datetime import datetime, timedelta
 from microt_compliance_matrix import utils
+from microt_compliance_matrix.utils.get_time_diff import *
 
 target_file_pattern = 'phone_battery_clean*.csv'
 
@@ -48,7 +49,7 @@ def clean_dataframe(df):
     dropped_rows = []
     for idx in df.index:
         local_time_str = df["Local_Time"][idx]
-        if (local_time_str == "-1") or len(local_time_str.split(' ')) > 3 or ("20212021" in local_time_str):
+        if (local_time_str == "-1") or len(local_time_str.split(' ')) > 3:
             dropped_rows.append(idx)
     df = df.drop(dropped_rows)
 
@@ -127,10 +128,16 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
 
             closest_time = find_closest_time(prompt_time, subset_time_list)
 
-            battery_level = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
-                                     "Percentage"])[0]
-            charging_status = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
-                                       "isCharging"])[0]
+            # check if matched time is 5 minutes away from prompt time
+            if get_min_diff(prompt_time, closest_time) < 5:
+                battery_level = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
+                                         "Percentage"])[0]
+                charging_status = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
+                                           "isCharging"])[0]
+            else:
+                battery_level = np.nan
+                charging_status = np.nan
+
 
         matched_time_list.append(closest_time)
         matched_battery_level_list.append(battery_level)
