@@ -90,9 +90,9 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
         # prompt_date = prompt_time.date()
 
         if df_logs_combined.shape[0] == 0:
-            matched_mims_summary_list = [np.nan] * len(min_before_list)
-            matched_readings_list = [np.nan] * len(min_before_list)
-            matched_start_time_list = [np.nan] * len(min_before_list)
+            matched_mims_summary_list = ["NF"] * len(min_before_list)
+            matched_readings_list = ["NF"] * len(min_before_list)
+            matched_start_time_list = ["NF"] * len(min_before_list)
         else:
             subset_time_list = list(df_logs_combined["TIME_DATETIME"])
             pos = find_closest_time(prompt_time, subset_time_list)
